api_pb

package
v0.0.0-...-65b9d13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2019 License: MIT Imports: 15 Imported by: 0

Documentation

Overview

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Package api_pb is a reverse proxy.

It translates gRPC into RESTful JSON APIs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterAdminServiceHandler

func RegisterAdminServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterAdminServiceHandler registers the http handlers for service AdminService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterAdminServiceHandlerClient

func RegisterAdminServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client AdminServiceClient) error

RegisterAdminServiceHandlerClient registers the http handlers for service AdminService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "AdminServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "AdminServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "AdminServiceClient" to call the correct interceptors.

func RegisterAdminServiceHandlerFromEndpoint

func RegisterAdminServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterAdminServiceHandlerFromEndpoint is same as RegisterAdminServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterAdminServiceServer

func RegisterAdminServiceServer(s *grpc.Server, srv AdminServiceServer)

func RegisterClassRoomServiceHandler

func RegisterClassRoomServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterClassRoomServiceHandler registers the http handlers for service ClassRoomService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterClassRoomServiceHandlerClient

func RegisterClassRoomServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client ClassRoomServiceClient) error

RegisterClassRoomServiceHandlerClient registers the http handlers for service ClassRoomService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "ClassRoomServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "ClassRoomServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "ClassRoomServiceClient" to call the correct interceptors.

func RegisterClassRoomServiceHandlerFromEndpoint

func RegisterClassRoomServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterClassRoomServiceHandlerFromEndpoint is same as RegisterClassRoomServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterClassRoomServiceServer

func RegisterClassRoomServiceServer(s *grpc.Server, srv ClassRoomServiceServer)

func RegisterSessionServiceHandler

func RegisterSessionServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterSessionServiceHandler registers the http handlers for service SessionService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterSessionServiceHandlerClient

func RegisterSessionServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client SessionServiceClient) error

RegisterSessionServiceHandlerClient registers the http handlers for service SessionService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "SessionServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "SessionServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "SessionServiceClient" to call the correct interceptors.

func RegisterSessionServiceHandlerFromEndpoint

func RegisterSessionServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterSessionServiceHandlerFromEndpoint is same as RegisterSessionServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterSessionServiceServer

func RegisterSessionServiceServer(s *grpc.Server, srv SessionServiceServer)

func RegisterTagServiceHandler

func RegisterTagServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterTagServiceHandler registers the http handlers for service TagService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterTagServiceHandlerClient

func RegisterTagServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client TagServiceClient) error

RegisterTagServiceHandlerClient registers the http handlers for service TagService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "TagServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "TagServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "TagServiceClient" to call the correct interceptors.

func RegisterTagServiceHandlerFromEndpoint

func RegisterTagServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterTagServiceHandlerFromEndpoint is same as RegisterTagServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterTagServiceServer

func RegisterTagServiceServer(s *grpc.Server, srv TagServiceServer)

func RegisterUserPositionServiceHandler

func RegisterUserPositionServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterUserPositionServiceHandler registers the http handlers for service UserPositionService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterUserPositionServiceHandlerClient

func RegisterUserPositionServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client UserPositionServiceClient) error

RegisterUserPositionServiceHandlerClient registers the http handlers for service UserPositionService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "UserPositionServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "UserPositionServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "UserPositionServiceClient" to call the correct interceptors.

func RegisterUserPositionServiceHandlerFromEndpoint

func RegisterUserPositionServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterUserPositionServiceHandlerFromEndpoint is same as RegisterUserPositionServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterUserPositionServiceServer

func RegisterUserPositionServiceServer(s *grpc.Server, srv UserPositionServiceServer)

func RegisterUserServiceHandler

func RegisterUserServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterUserServiceHandler registers the http handlers for service UserService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterUserServiceHandlerClient

func RegisterUserServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client UserServiceClient) error

RegisterUserServiceHandlerClient registers the http handlers for service UserService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "UserServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "UserServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "UserServiceClient" to call the correct interceptors.

func RegisterUserServiceHandlerFromEndpoint

func RegisterUserServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterUserServiceHandlerFromEndpoint is same as RegisterUserServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterUserServiceServer

func RegisterUserServiceServer(s *grpc.Server, srv UserServiceServer)

func RegisterUserTagServiceHandler

func RegisterUserTagServiceHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error

RegisterUserTagServiceHandler registers the http handlers for service UserTagService to "mux". The handlers forward requests to the grpc endpoint over "conn".

func RegisterUserTagServiceHandlerClient

func RegisterUserTagServiceHandlerClient(ctx context.Context, mux *runtime.ServeMux, client UserTagServiceClient) error

RegisterUserTagServiceHandlerClient registers the http handlers for service UserTagService to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "UserTagServiceClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "UserTagServiceClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "UserTagServiceClient" to call the correct interceptors.

func RegisterUserTagServiceHandlerFromEndpoint

func RegisterUserTagServiceHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)

RegisterUserTagServiceHandlerFromEndpoint is same as RegisterUserTagServiceHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.

func RegisterUserTagServiceServer

func RegisterUserTagServiceServer(s *grpc.Server, srv UserTagServiceServer)

Types

type AdminServiceClient

type AdminServiceClient interface {
	ImportBuildings(ctx context.Context, in *ImportBuildingsRequest, opts ...grpc.CallOption) (*ImportBuildingsResponse, error)
}

AdminServiceClient is the client API for AdminService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewAdminServiceClient

func NewAdminServiceClient(cc *grpc.ClientConn) AdminServiceClient

type AdminServiceServer

type AdminServiceServer interface {
	ImportBuildings(context.Context, *ImportBuildingsRequest) (*ImportBuildingsResponse, error)
}

AdminServiceServer is the server API for AdminService service.

type ClassRoom

type ClassRoom struct {
	ClassRoomId          int32           `protobuf:"varint,1,opt,name=class_room_id,json=classRoomId,proto3" json:"class_room_id,omitempty"`
	Name                 string          `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	TagCounts            []*TagCount     `protobuf:"bytes,5,rep,name=tag_counts,json=tagCounts,proto3" json:"tag_counts,omitempty"`
	Beacons              []*_type.Beacon `protobuf:"bytes,7,rep,name=beacons,proto3" json:"beacons,omitempty"`
	Floor                int32           `protobuf:"varint,8,opt,name=floor,proto3" json:"floor,omitempty"`
	LocalX               float64         `protobuf:"fixed64,9,opt,name=local_x,json=localX,proto3" json:"local_x,omitempty"`
	LocalY               float64         `protobuf:"fixed64,10,opt,name=local_y,json=localY,proto3" json:"local_y,omitempty"`
	Building             *_type.Building `protobuf:"bytes,11,opt,name=building,proto3" json:"building,omitempty"`
	XXX_NoUnkeyedLiteral struct{}        `json:"-"`
	XXX_unrecognized     []byte          `json:"-"`
	XXX_sizecache        int32           `json:"-"`
}

func (*ClassRoom) Descriptor

func (*ClassRoom) Descriptor() ([]byte, []int)

func (*ClassRoom) GetBeacons

func (m *ClassRoom) GetBeacons() []*_type.Beacon

func (*ClassRoom) GetBuilding

func (m *ClassRoom) GetBuilding() *_type.Building

func (*ClassRoom) GetClassRoomId

func (m *ClassRoom) GetClassRoomId() int32

func (*ClassRoom) GetFloor

func (m *ClassRoom) GetFloor() int32

func (*ClassRoom) GetLocalX

func (m *ClassRoom) GetLocalX() float64

func (*ClassRoom) GetLocalY

func (m *ClassRoom) GetLocalY() float64

func (*ClassRoom) GetName

func (m *ClassRoom) GetName() string

func (*ClassRoom) GetTagCounts

func (m *ClassRoom) GetTagCounts() []*TagCount

func (*ClassRoom) ProtoMessage

func (*ClassRoom) ProtoMessage()

func (*ClassRoom) Reset

func (m *ClassRoom) Reset()

func (*ClassRoom) String

func (m *ClassRoom) String() string

func (*ClassRoom) XXX_DiscardUnknown

func (m *ClassRoom) XXX_DiscardUnknown()

func (*ClassRoom) XXX_Marshal

func (m *ClassRoom) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ClassRoom) XXX_Merge

func (dst *ClassRoom) XXX_Merge(src proto.Message)

func (*ClassRoom) XXX_Size

func (m *ClassRoom) XXX_Size() int

func (*ClassRoom) XXX_Unmarshal

func (m *ClassRoom) XXX_Unmarshal(b []byte) error

type ClassRoomServiceClient

type ClassRoomServiceClient interface {
	ListClassRooms(ctx context.Context, in *ListClassRoomsRequest, opts ...grpc.CallOption) (*ListClassRoomsResponse, error)
	GetClassRoom(ctx context.Context, in *GetClassRoomRequest, opts ...grpc.CallOption) (*ClassRoom, error)
	CreateClassRoom(ctx context.Context, in *CreateClassRoomRequest, opts ...grpc.CallOption) (*ClassRoom, error)
	UpdateClassRoom(ctx context.Context, in *UpdateClassRoomRequest, opts ...grpc.CallOption) (*ClassRoom, error)
	DeleteClassRoom(ctx context.Context, in *DeleteClassRoomRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}

ClassRoomServiceClient is the client API for ClassRoomService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewClassRoomServiceClient

func NewClassRoomServiceClient(cc *grpc.ClientConn) ClassRoomServiceClient

type ClassRoomServiceServer

type ClassRoomServiceServer interface {
	ListClassRooms(context.Context, *ListClassRoomsRequest) (*ListClassRoomsResponse, error)
	GetClassRoom(context.Context, *GetClassRoomRequest) (*ClassRoom, error)
	CreateClassRoom(context.Context, *CreateClassRoomRequest) (*ClassRoom, error)
	UpdateClassRoom(context.Context, *UpdateClassRoomRequest) (*ClassRoom, error)
	DeleteClassRoom(context.Context, *DeleteClassRoomRequest) (*empty.Empty, error)
}

ClassRoomServiceServer is the server API for ClassRoomService service.

type CreateClassRoomRequest

type CreateClassRoomRequest struct {
	ClassRoom            *ClassRoom `protobuf:"bytes,1,opt,name=class_room,json=classRoom,proto3" json:"class_room,omitempty"`
	XXX_NoUnkeyedLiteral struct{}   `json:"-"`
	XXX_unrecognized     []byte     `json:"-"`
	XXX_sizecache        int32      `json:"-"`
}

func (*CreateClassRoomRequest) Descriptor

func (*CreateClassRoomRequest) Descriptor() ([]byte, []int)

func (*CreateClassRoomRequest) GetClassRoom

func (m *CreateClassRoomRequest) GetClassRoom() *ClassRoom

func (*CreateClassRoomRequest) ProtoMessage

func (*CreateClassRoomRequest) ProtoMessage()

func (*CreateClassRoomRequest) Reset

func (m *CreateClassRoomRequest) Reset()

func (*CreateClassRoomRequest) String

func (m *CreateClassRoomRequest) String() string

func (*CreateClassRoomRequest) XXX_DiscardUnknown

func (m *CreateClassRoomRequest) XXX_DiscardUnknown()

func (*CreateClassRoomRequest) XXX_Marshal

func (m *CreateClassRoomRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CreateClassRoomRequest) XXX_Merge

func (dst *CreateClassRoomRequest) XXX_Merge(src proto.Message)

func (*CreateClassRoomRequest) XXX_Size

func (m *CreateClassRoomRequest) XXX_Size() int

func (*CreateClassRoomRequest) XXX_Unmarshal

func (m *CreateClassRoomRequest) XXX_Unmarshal(b []byte) error

type CreateSessionRequest

type CreateSessionRequest struct {
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Password             string   `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*CreateSessionRequest) Descriptor

func (*CreateSessionRequest) Descriptor() ([]byte, []int)

func (*CreateSessionRequest) GetName

func (m *CreateSessionRequest) GetName() string

func (*CreateSessionRequest) GetPassword

func (m *CreateSessionRequest) GetPassword() string

func (*CreateSessionRequest) ProtoMessage

func (*CreateSessionRequest) ProtoMessage()

func (*CreateSessionRequest) Reset

func (m *CreateSessionRequest) Reset()

func (*CreateSessionRequest) String

func (m *CreateSessionRequest) String() string

func (*CreateSessionRequest) XXX_DiscardUnknown

func (m *CreateSessionRequest) XXX_DiscardUnknown()

func (*CreateSessionRequest) XXX_Marshal

func (m *CreateSessionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CreateSessionRequest) XXX_Merge

func (dst *CreateSessionRequest) XXX_Merge(src proto.Message)

func (*CreateSessionRequest) XXX_Size

func (m *CreateSessionRequest) XXX_Size() int

func (*CreateSessionRequest) XXX_Unmarshal

func (m *CreateSessionRequest) XXX_Unmarshal(b []byte) error

type CreateTagRequest

type CreateTagRequest struct {
	Tag                  *Tag     `protobuf:"bytes,1,opt,name=tag,proto3" json:"tag,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*CreateTagRequest) Descriptor

func (*CreateTagRequest) Descriptor() ([]byte, []int)

func (*CreateTagRequest) GetTag

func (m *CreateTagRequest) GetTag() *Tag

func (*CreateTagRequest) ProtoMessage

func (*CreateTagRequest) ProtoMessage()

func (*CreateTagRequest) Reset

func (m *CreateTagRequest) Reset()

func (*CreateTagRequest) String

func (m *CreateTagRequest) String() string

func (*CreateTagRequest) XXX_DiscardUnknown

func (m *CreateTagRequest) XXX_DiscardUnknown()

func (*CreateTagRequest) XXX_Marshal

func (m *CreateTagRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CreateTagRequest) XXX_Merge

func (dst *CreateTagRequest) XXX_Merge(src proto.Message)

func (*CreateTagRequest) XXX_Size

func (m *CreateTagRequest) XXX_Size() int

func (*CreateTagRequest) XXX_Unmarshal

func (m *CreateTagRequest) XXX_Unmarshal(b []byte) error

type CreateUserRequest

type CreateUserRequest struct {
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Password             string   `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*CreateUserRequest) Descriptor

func (*CreateUserRequest) Descriptor() ([]byte, []int)

func (*CreateUserRequest) GetName

func (m *CreateUserRequest) GetName() string

func (*CreateUserRequest) GetPassword

func (m *CreateUserRequest) GetPassword() string

func (*CreateUserRequest) ProtoMessage

func (*CreateUserRequest) ProtoMessage()

func (*CreateUserRequest) Reset

func (m *CreateUserRequest) Reset()

func (*CreateUserRequest) String

func (m *CreateUserRequest) String() string

func (*CreateUserRequest) XXX_DiscardUnknown

func (m *CreateUserRequest) XXX_DiscardUnknown()

func (*CreateUserRequest) XXX_Marshal

func (m *CreateUserRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*CreateUserRequest) XXX_Merge

func (dst *CreateUserRequest) XXX_Merge(src proto.Message)

func (*CreateUserRequest) XXX_Size

func (m *CreateUserRequest) XXX_Size() int

func (*CreateUserRequest) XXX_Unmarshal

func (m *CreateUserRequest) XXX_Unmarshal(b []byte) error

type DeleteClassRoomRequest

type DeleteClassRoomRequest struct {
	ClassRoomId          int32    `protobuf:"varint,1,opt,name=class_room_id,json=classRoomId,proto3" json:"class_room_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*DeleteClassRoomRequest) Descriptor

func (*DeleteClassRoomRequest) Descriptor() ([]byte, []int)

func (*DeleteClassRoomRequest) GetClassRoomId

func (m *DeleteClassRoomRequest) GetClassRoomId() int32

func (*DeleteClassRoomRequest) ProtoMessage

func (*DeleteClassRoomRequest) ProtoMessage()

func (*DeleteClassRoomRequest) Reset

func (m *DeleteClassRoomRequest) Reset()

func (*DeleteClassRoomRequest) String

func (m *DeleteClassRoomRequest) String() string

func (*DeleteClassRoomRequest) XXX_DiscardUnknown

func (m *DeleteClassRoomRequest) XXX_DiscardUnknown()

func (*DeleteClassRoomRequest) XXX_Marshal

func (m *DeleteClassRoomRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*DeleteClassRoomRequest) XXX_Merge

func (dst *DeleteClassRoomRequest) XXX_Merge(src proto.Message)

func (*DeleteClassRoomRequest) XXX_Size

func (m *DeleteClassRoomRequest) XXX_Size() int

func (*DeleteClassRoomRequest) XXX_Unmarshal

func (m *DeleteClassRoomRequest) XXX_Unmarshal(b []byte) error

type DeleteSessionRequest

type DeleteSessionRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*DeleteSessionRequest) Descriptor

func (*DeleteSessionRequest) Descriptor() ([]byte, []int)

func (*DeleteSessionRequest) ProtoMessage

func (*DeleteSessionRequest) ProtoMessage()

func (*DeleteSessionRequest) Reset

func (m *DeleteSessionRequest) Reset()

func (*DeleteSessionRequest) String

func (m *DeleteSessionRequest) String() string

func (*DeleteSessionRequest) XXX_DiscardUnknown

func (m *DeleteSessionRequest) XXX_DiscardUnknown()

func (*DeleteSessionRequest) XXX_Marshal

func (m *DeleteSessionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*DeleteSessionRequest) XXX_Merge

func (dst *DeleteSessionRequest) XXX_Merge(src proto.Message)

func (*DeleteSessionRequest) XXX_Size

func (m *DeleteSessionRequest) XXX_Size() int

func (*DeleteSessionRequest) XXX_Unmarshal

func (m *DeleteSessionRequest) XXX_Unmarshal(b []byte) error

type GetClassRoomRequest

type GetClassRoomRequest struct {
	ClassRoomId          int32    `protobuf:"varint,1,opt,name=class_room_id,json=classRoomId,proto3" json:"class_room_id,omitempty"`
	TagIds               []int32  `protobuf:"varint,2,rep,packed,name=tag_ids,json=tagIds,proto3" json:"tag_ids,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetClassRoomRequest) Descriptor

func (*GetClassRoomRequest) Descriptor() ([]byte, []int)

func (*GetClassRoomRequest) GetClassRoomId

func (m *GetClassRoomRequest) GetClassRoomId() int32

func (*GetClassRoomRequest) GetTagIds

func (m *GetClassRoomRequest) GetTagIds() []int32

func (*GetClassRoomRequest) ProtoMessage

func (*GetClassRoomRequest) ProtoMessage()

func (*GetClassRoomRequest) Reset

func (m *GetClassRoomRequest) Reset()

func (*GetClassRoomRequest) String

func (m *GetClassRoomRequest) String() string

func (*GetClassRoomRequest) XXX_DiscardUnknown

func (m *GetClassRoomRequest) XXX_DiscardUnknown()

func (*GetClassRoomRequest) XXX_Marshal

func (m *GetClassRoomRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetClassRoomRequest) XXX_Merge

func (dst *GetClassRoomRequest) XXX_Merge(src proto.Message)

func (*GetClassRoomRequest) XXX_Size

func (m *GetClassRoomRequest) XXX_Size() int

func (*GetClassRoomRequest) XXX_Unmarshal

func (m *GetClassRoomRequest) XXX_Unmarshal(b []byte) error

type GetCurrentUserRequest

type GetCurrentUserRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetCurrentUserRequest) Descriptor

func (*GetCurrentUserRequest) Descriptor() ([]byte, []int)

func (*GetCurrentUserRequest) ProtoMessage

func (*GetCurrentUserRequest) ProtoMessage()

func (*GetCurrentUserRequest) Reset

func (m *GetCurrentUserRequest) Reset()

func (*GetCurrentUserRequest) String

func (m *GetCurrentUserRequest) String() string

func (*GetCurrentUserRequest) XXX_DiscardUnknown

func (m *GetCurrentUserRequest) XXX_DiscardUnknown()

func (*GetCurrentUserRequest) XXX_Marshal

func (m *GetCurrentUserRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetCurrentUserRequest) XXX_Merge

func (dst *GetCurrentUserRequest) XXX_Merge(src proto.Message)

func (*GetCurrentUserRequest) XXX_Size

func (m *GetCurrentUserRequest) XXX_Size() int

func (*GetCurrentUserRequest) XXX_Unmarshal

func (m *GetCurrentUserRequest) XXX_Unmarshal(b []byte) error

type GetTagRequest

type GetTagRequest struct {
	TagId                int32    `protobuf:"varint,1,opt,name=tag_id,json=tagId,proto3" json:"tag_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetTagRequest) Descriptor

func (*GetTagRequest) Descriptor() ([]byte, []int)

func (*GetTagRequest) GetTagId

func (m *GetTagRequest) GetTagId() int32

func (*GetTagRequest) ProtoMessage

func (*GetTagRequest) ProtoMessage()

func (*GetTagRequest) Reset

func (m *GetTagRequest) Reset()

func (*GetTagRequest) String

func (m *GetTagRequest) String() string

func (*GetTagRequest) XXX_DiscardUnknown

func (m *GetTagRequest) XXX_DiscardUnknown()

func (*GetTagRequest) XXX_Marshal

func (m *GetTagRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetTagRequest) XXX_Merge

func (dst *GetTagRequest) XXX_Merge(src proto.Message)

func (*GetTagRequest) XXX_Size

func (m *GetTagRequest) XXX_Size() int

func (*GetTagRequest) XXX_Unmarshal

func (m *GetTagRequest) XXX_Unmarshal(b []byte) error

type GetUserPositionRequest

type GetUserPositionRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetUserPositionRequest) Descriptor

func (*GetUserPositionRequest) Descriptor() ([]byte, []int)

func (*GetUserPositionRequest) ProtoMessage

func (*GetUserPositionRequest) ProtoMessage()

func (*GetUserPositionRequest) Reset

func (m *GetUserPositionRequest) Reset()

func (*GetUserPositionRequest) String

func (m *GetUserPositionRequest) String() string

func (*GetUserPositionRequest) XXX_DiscardUnknown

func (m *GetUserPositionRequest) XXX_DiscardUnknown()

func (*GetUserPositionRequest) XXX_Marshal

func (m *GetUserPositionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetUserPositionRequest) XXX_Merge

func (dst *GetUserPositionRequest) XXX_Merge(src proto.Message)

func (*GetUserPositionRequest) XXX_Size

func (m *GetUserPositionRequest) XXX_Size() int

func (*GetUserPositionRequest) XXX_Unmarshal

func (m *GetUserPositionRequest) XXX_Unmarshal(b []byte) error

type GetUserRequest

type GetUserRequest struct {
	UserId               uint32   `protobuf:"varint,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*GetUserRequest) Descriptor

func (*GetUserRequest) Descriptor() ([]byte, []int)

func (*GetUserRequest) GetUserId

func (m *GetUserRequest) GetUserId() uint32

func (*GetUserRequest) ProtoMessage

func (*GetUserRequest) ProtoMessage()

func (*GetUserRequest) Reset

func (m *GetUserRequest) Reset()

func (*GetUserRequest) String

func (m *GetUserRequest) String() string

func (*GetUserRequest) XXX_DiscardUnknown

func (m *GetUserRequest) XXX_DiscardUnknown()

func (*GetUserRequest) XXX_Marshal

func (m *GetUserRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*GetUserRequest) XXX_Merge

func (dst *GetUserRequest) XXX_Merge(src proto.Message)

func (*GetUserRequest) XXX_Size

func (m *GetUserRequest) XXX_Size() int

func (*GetUserRequest) XXX_Unmarshal

func (m *GetUserRequest) XXX_Unmarshal(b []byte) error

type ImportBuildingsRequest

type ImportBuildingsRequest struct {
	Key                  string   `protobuf:"bytes,1,opt,name=key,proto3" json:"key,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ImportBuildingsRequest) Descriptor

func (*ImportBuildingsRequest) Descriptor() ([]byte, []int)

func (*ImportBuildingsRequest) GetKey

func (m *ImportBuildingsRequest) GetKey() string

func (*ImportBuildingsRequest) ProtoMessage

func (*ImportBuildingsRequest) ProtoMessage()

func (*ImportBuildingsRequest) Reset

func (m *ImportBuildingsRequest) Reset()

func (*ImportBuildingsRequest) String

func (m *ImportBuildingsRequest) String() string

func (*ImportBuildingsRequest) XXX_DiscardUnknown

func (m *ImportBuildingsRequest) XXX_DiscardUnknown()

func (*ImportBuildingsRequest) XXX_Marshal

func (m *ImportBuildingsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ImportBuildingsRequest) XXX_Merge

func (dst *ImportBuildingsRequest) XXX_Merge(src proto.Message)

func (*ImportBuildingsRequest) XXX_Size

func (m *ImportBuildingsRequest) XXX_Size() int

func (*ImportBuildingsRequest) XXX_Unmarshal

func (m *ImportBuildingsRequest) XXX_Unmarshal(b []byte) error

type ImportBuildingsResponse

type ImportBuildingsResponse struct {
	Message              string   `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ImportBuildingsResponse) Descriptor

func (*ImportBuildingsResponse) Descriptor() ([]byte, []int)

func (*ImportBuildingsResponse) GetMessage

func (m *ImportBuildingsResponse) GetMessage() string

func (*ImportBuildingsResponse) ProtoMessage

func (*ImportBuildingsResponse) ProtoMessage()

func (*ImportBuildingsResponse) Reset

func (m *ImportBuildingsResponse) Reset()

func (*ImportBuildingsResponse) String

func (m *ImportBuildingsResponse) String() string

func (*ImportBuildingsResponse) XXX_DiscardUnknown

func (m *ImportBuildingsResponse) XXX_DiscardUnknown()

func (*ImportBuildingsResponse) XXX_Marshal

func (m *ImportBuildingsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ImportBuildingsResponse) XXX_Merge

func (dst *ImportBuildingsResponse) XXX_Merge(src proto.Message)

func (*ImportBuildingsResponse) XXX_Size

func (m *ImportBuildingsResponse) XXX_Size() int

func (*ImportBuildingsResponse) XXX_Unmarshal

func (m *ImportBuildingsResponse) XXX_Unmarshal(b []byte) error

type ListClassRoomsRequest

type ListClassRoomsRequest struct {
	TagIds               []int32  `protobuf:"varint,1,rep,packed,name=tag_ids,json=tagIds,proto3" json:"tag_ids,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ListClassRoomsRequest) Descriptor

func (*ListClassRoomsRequest) Descriptor() ([]byte, []int)

func (*ListClassRoomsRequest) GetTagIds

func (m *ListClassRoomsRequest) GetTagIds() []int32

func (*ListClassRoomsRequest) ProtoMessage

func (*ListClassRoomsRequest) ProtoMessage()

func (*ListClassRoomsRequest) Reset

func (m *ListClassRoomsRequest) Reset()

func (*ListClassRoomsRequest) String

func (m *ListClassRoomsRequest) String() string

func (*ListClassRoomsRequest) XXX_DiscardUnknown

func (m *ListClassRoomsRequest) XXX_DiscardUnknown()

func (*ListClassRoomsRequest) XXX_Marshal

func (m *ListClassRoomsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListClassRoomsRequest) XXX_Merge

func (dst *ListClassRoomsRequest) XXX_Merge(src proto.Message)

func (*ListClassRoomsRequest) XXX_Size

func (m *ListClassRoomsRequest) XXX_Size() int

func (*ListClassRoomsRequest) XXX_Unmarshal

func (m *ListClassRoomsRequest) XXX_Unmarshal(b []byte) error

type ListClassRoomsResponse

type ListClassRoomsResponse struct {
	ClassRooms           []*ClassRoom `protobuf:"bytes,1,rep,name=class_rooms,json=classRooms,proto3" json:"class_rooms,omitempty"`
	XXX_NoUnkeyedLiteral struct{}     `json:"-"`
	XXX_unrecognized     []byte       `json:"-"`
	XXX_sizecache        int32        `json:"-"`
}

func (*ListClassRoomsResponse) Descriptor

func (*ListClassRoomsResponse) Descriptor() ([]byte, []int)

func (*ListClassRoomsResponse) GetClassRooms

func (m *ListClassRoomsResponse) GetClassRooms() []*ClassRoom

func (*ListClassRoomsResponse) ProtoMessage

func (*ListClassRoomsResponse) ProtoMessage()

func (*ListClassRoomsResponse) Reset

func (m *ListClassRoomsResponse) Reset()

func (*ListClassRoomsResponse) String

func (m *ListClassRoomsResponse) String() string

func (*ListClassRoomsResponse) XXX_DiscardUnknown

func (m *ListClassRoomsResponse) XXX_DiscardUnknown()

func (*ListClassRoomsResponse) XXX_Marshal

func (m *ListClassRoomsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListClassRoomsResponse) XXX_Merge

func (dst *ListClassRoomsResponse) XXX_Merge(src proto.Message)

func (*ListClassRoomsResponse) XXX_Size

func (m *ListClassRoomsResponse) XXX_Size() int

func (*ListClassRoomsResponse) XXX_Unmarshal

func (m *ListClassRoomsResponse) XXX_Unmarshal(b []byte) error

type ListTagsRequest

type ListTagsRequest struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ListTagsRequest) Descriptor

func (*ListTagsRequest) Descriptor() ([]byte, []int)

func (*ListTagsRequest) ProtoMessage

func (*ListTagsRequest) ProtoMessage()

func (*ListTagsRequest) Reset

func (m *ListTagsRequest) Reset()

func (*ListTagsRequest) String

func (m *ListTagsRequest) String() string

func (*ListTagsRequest) XXX_DiscardUnknown

func (m *ListTagsRequest) XXX_DiscardUnknown()

func (*ListTagsRequest) XXX_Marshal

func (m *ListTagsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListTagsRequest) XXX_Merge

func (dst *ListTagsRequest) XXX_Merge(src proto.Message)

func (*ListTagsRequest) XXX_Size

func (m *ListTagsRequest) XXX_Size() int

func (*ListTagsRequest) XXX_Unmarshal

func (m *ListTagsRequest) XXX_Unmarshal(b []byte) error

type ListTagsResponse

type ListTagsResponse struct {
	Tags                 []*Tag   `protobuf:"bytes,1,rep,name=tags,proto3" json:"tags,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*ListTagsResponse) Descriptor

func (*ListTagsResponse) Descriptor() ([]byte, []int)

func (*ListTagsResponse) GetTags

func (m *ListTagsResponse) GetTags() []*Tag

func (*ListTagsResponse) ProtoMessage

func (*ListTagsResponse) ProtoMessage()

func (*ListTagsResponse) Reset

func (m *ListTagsResponse) Reset()

func (*ListTagsResponse) String

func (m *ListTagsResponse) String() string

func (*ListTagsResponse) XXX_DiscardUnknown

func (m *ListTagsResponse) XXX_DiscardUnknown()

func (*ListTagsResponse) XXX_Marshal

func (m *ListTagsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ListTagsResponse) XXX_Merge

func (dst *ListTagsResponse) XXX_Merge(src proto.Message)

func (*ListTagsResponse) XXX_Size

func (m *ListTagsResponse) XXX_Size() int

func (*ListTagsResponse) XXX_Unmarshal

func (m *ListTagsResponse) XXX_Unmarshal(b []byte) error

type Session

type Session struct {
	SessionId            string   `protobuf:"bytes,1,opt,name=session_id,json=sessionId,proto3" json:"session_id,omitempty"`
	UesrId               uint32   `protobuf:"varint,2,opt,name=uesr_id,json=uesrId,proto3" json:"uesr_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Session) Descriptor

func (*Session) Descriptor() ([]byte, []int)

func (*Session) GetSessionId

func (m *Session) GetSessionId() string

func (*Session) GetUesrId

func (m *Session) GetUesrId() uint32

func (*Session) ProtoMessage

func (*Session) ProtoMessage()

func (*Session) Reset

func (m *Session) Reset()

func (*Session) String

func (m *Session) String() string

func (*Session) XXX_DiscardUnknown

func (m *Session) XXX_DiscardUnknown()

func (*Session) XXX_Marshal

func (m *Session) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Session) XXX_Merge

func (dst *Session) XXX_Merge(src proto.Message)

func (*Session) XXX_Size

func (m *Session) XXX_Size() int

func (*Session) XXX_Unmarshal

func (m *Session) XXX_Unmarshal(b []byte) error

type SessionServiceClient

type SessionServiceClient interface {
	CreateSession(ctx context.Context, in *CreateSessionRequest, opts ...grpc.CallOption) (*Session, error)
	DeleteSession(ctx context.Context, in *DeleteSessionRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}

SessionServiceClient is the client API for SessionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewSessionServiceClient

func NewSessionServiceClient(cc *grpc.ClientConn) SessionServiceClient

type SessionServiceServer

type SessionServiceServer interface {
	CreateSession(context.Context, *CreateSessionRequest) (*Session, error)
	DeleteSession(context.Context, *DeleteSessionRequest) (*empty.Empty, error)
}

SessionServiceServer is the server API for SessionService service.

type Tag

type Tag struct {
	Id                   int32    `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Name                 string   `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Total                int32    `protobuf:"varint,3,opt,name=total,proto3" json:"total,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*Tag) Descriptor

func (*Tag) Descriptor() ([]byte, []int)

func (*Tag) GetId

func (m *Tag) GetId() int32

func (*Tag) GetName

func (m *Tag) GetName() string

func (*Tag) GetTotal

func (m *Tag) GetTotal() int32

func (*Tag) ProtoMessage

func (*Tag) ProtoMessage()

func (*Tag) Reset

func (m *Tag) Reset()

func (*Tag) String

func (m *Tag) String() string

func (*Tag) XXX_DiscardUnknown

func (m *Tag) XXX_DiscardUnknown()

func (*Tag) XXX_Marshal

func (m *Tag) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*Tag) XXX_Merge

func (dst *Tag) XXX_Merge(src proto.Message)

func (*Tag) XXX_Size

func (m *Tag) XXX_Size() int

func (*Tag) XXX_Unmarshal

func (m *Tag) XXX_Unmarshal(b []byte) error

type TagCount

type TagCount struct {
	Tag                  *Tag     `protobuf:"bytes,1,opt,name=tag,proto3" json:"tag,omitempty"`
	Count                int32    `protobuf:"varint,2,opt,name=count,proto3" json:"count,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*TagCount) Descriptor

func (*TagCount) Descriptor() ([]byte, []int)

func (*TagCount) GetCount

func (m *TagCount) GetCount() int32

func (*TagCount) GetTag

func (m *TagCount) GetTag() *Tag

func (*TagCount) ProtoMessage

func (*TagCount) ProtoMessage()

func (*TagCount) Reset

func (m *TagCount) Reset()

func (*TagCount) String

func (m *TagCount) String() string

func (*TagCount) XXX_DiscardUnknown

func (m *TagCount) XXX_DiscardUnknown()

func (*TagCount) XXX_Marshal

func (m *TagCount) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*TagCount) XXX_Merge

func (dst *TagCount) XXX_Merge(src proto.Message)

func (*TagCount) XXX_Size

func (m *TagCount) XXX_Size() int

func (*TagCount) XXX_Unmarshal

func (m *TagCount) XXX_Unmarshal(b []byte) error

type TagServiceClient

type TagServiceClient interface {
	ListTags(ctx context.Context, in *ListTagsRequest, opts ...grpc.CallOption) (*ListTagsResponse, error)
	GetTag(ctx context.Context, in *GetTagRequest, opts ...grpc.CallOption) (*Tag, error)
	CreateTag(ctx context.Context, in *CreateTagRequest, opts ...grpc.CallOption) (*Tag, error)
}

TagServiceClient is the client API for TagService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewTagServiceClient

func NewTagServiceClient(cc *grpc.ClientConn) TagServiceClient

type TagServiceServer

type TagServiceServer interface {
	ListTags(context.Context, *ListTagsRequest) (*ListTagsResponse, error)
	GetTag(context.Context, *GetTagRequest) (*Tag, error)
	CreateTag(context.Context, *CreateTagRequest) (*Tag, error)
}

TagServiceServer is the server API for TagService service.

type UpdateClassRoomRequest

type UpdateClassRoomRequest struct {
	ClassRoom            *ClassRoom `protobuf:"bytes,1,opt,name=class_room,json=classRoom,proto3" json:"class_room,omitempty"`
	XXX_NoUnkeyedLiteral struct{}   `json:"-"`
	XXX_unrecognized     []byte     `json:"-"`
	XXX_sizecache        int32      `json:"-"`
}

func (*UpdateClassRoomRequest) Descriptor

func (*UpdateClassRoomRequest) Descriptor() ([]byte, []int)

func (*UpdateClassRoomRequest) GetClassRoom

func (m *UpdateClassRoomRequest) GetClassRoom() *ClassRoom

func (*UpdateClassRoomRequest) ProtoMessage

func (*UpdateClassRoomRequest) ProtoMessage()

func (*UpdateClassRoomRequest) Reset

func (m *UpdateClassRoomRequest) Reset()

func (*UpdateClassRoomRequest) String

func (m *UpdateClassRoomRequest) String() string

func (*UpdateClassRoomRequest) XXX_DiscardUnknown

func (m *UpdateClassRoomRequest) XXX_DiscardUnknown()

func (*UpdateClassRoomRequest) XXX_Marshal

func (m *UpdateClassRoomRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UpdateClassRoomRequest) XXX_Merge

func (dst *UpdateClassRoomRequest) XXX_Merge(src proto.Message)

func (*UpdateClassRoomRequest) XXX_Size

func (m *UpdateClassRoomRequest) XXX_Size() int

func (*UpdateClassRoomRequest) XXX_Unmarshal

func (m *UpdateClassRoomRequest) XXX_Unmarshal(b []byte) error

type UpdateUserPositionRequest

type UpdateUserPositionRequest struct {
	Bssid string `protobuf:"bytes,1,opt,name=bssid,proto3" json:"bssid,omitempty"`
	// beaconに接続している時にtrueにする
	IsValid              bool     `protobuf:"varint,2,opt,name=is_valid,json=isValid,proto3" json:"is_valid,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UpdateUserPositionRequest) Descriptor

func (*UpdateUserPositionRequest) Descriptor() ([]byte, []int)

func (*UpdateUserPositionRequest) GetBssid

func (m *UpdateUserPositionRequest) GetBssid() string

func (*UpdateUserPositionRequest) GetIsValid

func (m *UpdateUserPositionRequest) GetIsValid() bool

func (*UpdateUserPositionRequest) ProtoMessage

func (*UpdateUserPositionRequest) ProtoMessage()

func (*UpdateUserPositionRequest) Reset

func (m *UpdateUserPositionRequest) Reset()

func (*UpdateUserPositionRequest) String

func (m *UpdateUserPositionRequest) String() string

func (*UpdateUserPositionRequest) XXX_DiscardUnknown

func (m *UpdateUserPositionRequest) XXX_DiscardUnknown()

func (*UpdateUserPositionRequest) XXX_Marshal

func (m *UpdateUserPositionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UpdateUserPositionRequest) XXX_Merge

func (dst *UpdateUserPositionRequest) XXX_Merge(src proto.Message)

func (*UpdateUserPositionRequest) XXX_Size

func (m *UpdateUserPositionRequest) XXX_Size() int

func (*UpdateUserPositionRequest) XXX_Unmarshal

func (m *UpdateUserPositionRequest) XXX_Unmarshal(b []byte) error

type UpdateUserRequest

type UpdateUserRequest struct {
	User                 *User    `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UpdateUserRequest) Descriptor

func (*UpdateUserRequest) Descriptor() ([]byte, []int)

func (*UpdateUserRequest) GetUser

func (m *UpdateUserRequest) GetUser() *User

func (*UpdateUserRequest) ProtoMessage

func (*UpdateUserRequest) ProtoMessage()

func (*UpdateUserRequest) Reset

func (m *UpdateUserRequest) Reset()

func (*UpdateUserRequest) String

func (m *UpdateUserRequest) String() string

func (*UpdateUserRequest) XXX_DiscardUnknown

func (m *UpdateUserRequest) XXX_DiscardUnknown()

func (*UpdateUserRequest) XXX_Marshal

func (m *UpdateUserRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UpdateUserRequest) XXX_Merge

func (dst *UpdateUserRequest) XXX_Merge(src proto.Message)

func (*UpdateUserRequest) XXX_Size

func (m *UpdateUserRequest) XXX_Size() int

func (*UpdateUserRequest) XXX_Unmarshal

func (m *UpdateUserRequest) XXX_Unmarshal(b []byte) error

type UpdateUserTagRequest

type UpdateUserTagRequest struct {
	TagIds               []int32  `protobuf:"varint,1,rep,packed,name=tag_ids,json=tagIds,proto3" json:"tag_ids,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UpdateUserTagRequest) Descriptor

func (*UpdateUserTagRequest) Descriptor() ([]byte, []int)

func (*UpdateUserTagRequest) GetTagIds

func (m *UpdateUserTagRequest) GetTagIds() []int32

func (*UpdateUserTagRequest) ProtoMessage

func (*UpdateUserTagRequest) ProtoMessage()

func (*UpdateUserTagRequest) Reset

func (m *UpdateUserTagRequest) Reset()

func (*UpdateUserTagRequest) String

func (m *UpdateUserTagRequest) String() string

func (*UpdateUserTagRequest) XXX_DiscardUnknown

func (m *UpdateUserTagRequest) XXX_DiscardUnknown()

func (*UpdateUserTagRequest) XXX_Marshal

func (m *UpdateUserTagRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UpdateUserTagRequest) XXX_Merge

func (dst *UpdateUserTagRequest) XXX_Merge(src proto.Message)

func (*UpdateUserTagRequest) XXX_Size

func (m *UpdateUserTagRequest) XXX_Size() int

func (*UpdateUserTagRequest) XXX_Unmarshal

func (m *UpdateUserTagRequest) XXX_Unmarshal(b []byte) error

type UpdateUserTagResponse

type UpdateUserTagResponse struct {
	Tags                 []*Tag   `protobuf:"bytes,1,rep,name=tags,proto3" json:"tags,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*UpdateUserTagResponse) Descriptor

func (*UpdateUserTagResponse) Descriptor() ([]byte, []int)

func (*UpdateUserTagResponse) GetTags

func (m *UpdateUserTagResponse) GetTags() []*Tag

func (*UpdateUserTagResponse) ProtoMessage

func (*UpdateUserTagResponse) ProtoMessage()

func (*UpdateUserTagResponse) Reset

func (m *UpdateUserTagResponse) Reset()

func (*UpdateUserTagResponse) String

func (m *UpdateUserTagResponse) String() string

func (*UpdateUserTagResponse) XXX_DiscardUnknown

func (m *UpdateUserTagResponse) XXX_DiscardUnknown()

func (*UpdateUserTagResponse) XXX_Marshal

func (m *UpdateUserTagResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UpdateUserTagResponse) XXX_Merge

func (dst *UpdateUserTagResponse) XXX_Merge(src proto.Message)

func (*UpdateUserTagResponse) XXX_Size

func (m *UpdateUserTagResponse) XXX_Size() int

func (*UpdateUserTagResponse) XXX_Unmarshal

func (m *UpdateUserTagResponse) XXX_Unmarshal(b []byte) error

type User

type User struct {
	UserId               uint32   `protobuf:"varint,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`
	Name                 string   `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Tags                 []*Tag   `protobuf:"bytes,3,rep,name=tags,proto3" json:"tags,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (*User) Descriptor

func (*User) Descriptor() ([]byte, []int)

func (*User) GetName

func (m *User) GetName() string

func (*User) GetTags

func (m *User) GetTags() []*Tag

func (*User) GetUserId

func (m *User) GetUserId() uint32

func (*User) ProtoMessage

func (*User) ProtoMessage()

func (*User) Reset

func (m *User) Reset()

func (*User) String

func (m *User) String() string

func (*User) XXX_DiscardUnknown

func (m *User) XXX_DiscardUnknown()

func (*User) XXX_Marshal

func (m *User) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*User) XXX_Merge

func (dst *User) XXX_Merge(src proto.Message)

func (*User) XXX_Size

func (m *User) XXX_Size() int

func (*User) XXX_Unmarshal

func (m *User) XXX_Unmarshal(b []byte) error

type UserPosition

type UserPosition struct {
	ClassRoom            *ClassRoom `protobuf:"bytes,1,opt,name=class_room,json=classRoom,proto3" json:"class_room,omitempty"`
	IsValid              bool       `protobuf:"varint,2,opt,name=is_valid,json=isValid,proto3" json:"is_valid,omitempty"`
	XXX_NoUnkeyedLiteral struct{}   `json:"-"`
	XXX_unrecognized     []byte     `json:"-"`
	XXX_sizecache        int32      `json:"-"`
}

func (*UserPosition) Descriptor

func (*UserPosition) Descriptor() ([]byte, []int)

func (*UserPosition) GetClassRoom

func (m *UserPosition) GetClassRoom() *ClassRoom

func (*UserPosition) GetIsValid

func (m *UserPosition) GetIsValid() bool

func (*UserPosition) ProtoMessage

func (*UserPosition) ProtoMessage()

func (*UserPosition) Reset

func (m *UserPosition) Reset()

func (*UserPosition) String

func (m *UserPosition) String() string

func (*UserPosition) XXX_DiscardUnknown

func (m *UserPosition) XXX_DiscardUnknown()

func (*UserPosition) XXX_Marshal

func (m *UserPosition) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*UserPosition) XXX_Merge

func (dst *UserPosition) XXX_Merge(src proto.Message)

func (*UserPosition) XXX_Size

func (m *UserPosition) XXX_Size() int

func (*UserPosition) XXX_Unmarshal

func (m *UserPosition) XXX_Unmarshal(b []byte) error

type UserPositionServiceClient

type UserPositionServiceClient interface {
	GetUserPosition(ctx context.Context, in *GetUserPositionRequest, opts ...grpc.CallOption) (*UserPosition, error)
	UpdateUserPosition(ctx context.Context, in *UpdateUserPositionRequest, opts ...grpc.CallOption) (*UserPosition, error)
}

UserPositionServiceClient is the client API for UserPositionService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewUserPositionServiceClient

func NewUserPositionServiceClient(cc *grpc.ClientConn) UserPositionServiceClient

type UserPositionServiceServer

type UserPositionServiceServer interface {
	GetUserPosition(context.Context, *GetUserPositionRequest) (*UserPosition, error)
	UpdateUserPosition(context.Context, *UpdateUserPositionRequest) (*UserPosition, error)
}

UserPositionServiceServer is the server API for UserPositionService service.

type UserServiceClient

type UserServiceClient interface {
	GetCurrentUser(ctx context.Context, in *GetCurrentUserRequest, opts ...grpc.CallOption) (*User, error)
	UpdateUser(ctx context.Context, in *UpdateUserRequest, opts ...grpc.CallOption) (*User, error)
	GetUser(ctx context.Context, in *GetUserRequest, opts ...grpc.CallOption) (*User, error)
	CreateUser(ctx context.Context, in *CreateUserRequest, opts ...grpc.CallOption) (*User, error)
}

UserServiceClient is the client API for UserService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewUserServiceClient

func NewUserServiceClient(cc *grpc.ClientConn) UserServiceClient

type UserServiceServer

type UserServiceServer interface {
	GetCurrentUser(context.Context, *GetCurrentUserRequest) (*User, error)
	UpdateUser(context.Context, *UpdateUserRequest) (*User, error)
	GetUser(context.Context, *GetUserRequest) (*User, error)
	CreateUser(context.Context, *CreateUserRequest) (*User, error)
}

UserServiceServer is the server API for UserService service.

type UserTagServiceClient

type UserTagServiceClient interface {
	UpdateUserTag(ctx context.Context, in *UpdateUserTagRequest, opts ...grpc.CallOption) (*UpdateUserTagResponse, error)
}

UserTagServiceClient is the client API for UserTagService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewUserTagServiceClient

func NewUserTagServiceClient(cc *grpc.ClientConn) UserTagServiceClient

type UserTagServiceServer

type UserTagServiceServer interface {
	UpdateUserTag(context.Context, *UpdateUserTagRequest) (*UpdateUserTagResponse, error)
}

UserTagServiceServer is the server API for UserTagService service.

Directories

Path Synopsis

Jump to